import bpy

bl_info = {
    "name": "Kayuhitam Addon FIFA 14",
    "blender": (2, 80, 0),
    "category": "Object",
}

class OBJECT_OT_custom_transform(bpy.types.Operator):
    bl_idname = "object.custom_transform"
    bl_label = "Custom Transform"
    bl_options = {'REGISTER', 'UNDO'}

    def execute(self, context):
        # Access the active object
        obj = context.active_object
        if obj is not None:
            # Apply rotations and translations
            obj.rotation_euler[0] = -1.5708
            obj.location[2] = 0.02
        return {'FINISHED'}

def menu_func(self, context):
    self.layout.operator(OBJECT_OT_custom_transform.bl_idname)

def rename_uv_layers_():
    obj = bpy.context.object
    if obj.type == 'MESH':
        obj.data.uv_layers["map0"].name = "UVChannel0"
        obj.data.uv_layers["map1"].name = "UVChannel1"

def manipulate_vertex_colors():
    obj = bpy.context.object
    if obj.type == 'MESH':
        bpy.ops.mesh.vertex_color_remove()
        bpy.ops.mesh.vertex_color_remove()
        bpy.ops.mesh.vertex_color_add()
        obj.data.vertex_colors["Col"].name = "VColor1"

def transfer_weights():
    # Get selected objects
    selected_objects = bpy.context.selected_objects
    
    # Check if there are at least two selected objects
    if len(selected_objects) < 2:
        print("Please select at least two objects.")
        return
    
    # Activate the last selected object
    target_object = selected_objects[-1]
    bpy.context.view_layer.objects.active = target_object
    
    # Toggle weight paint mode
    bpy.ops.object.mode_set(mode='WEIGHT_PAINT')
    
    # Transfer weights from the first selected object to the last selected object
    source_object = selected_objects[0]
    bpy.context.view_layer.objects.active = source_object
    bpy.ops.object.mode_set(mode='WEIGHT_PAINT')
    bpy.ops.object.data_transfer(
        use_reverse_transfer=True,
        data_type='VGROUP_WEIGHTS',
        layers_select_src='NAME',
        layers_select_dst='ALL'
    )

class KayuhitamPanel(bpy.types.Panel):
    bl_label = "Kayuhitam Addon"
    bl_idname = "OBJECT_PT_kayuhitam"
    bl_space_type = 'VIEW_3D'
    bl_region_type = 'UI'
    bl_category = "Kayuhitam"

    def draw(self, context):
        layout = self.layout
        layout.operator("object.rename_uv_layers", text="FIFA 14 to FIFA 23 UV")
        layout.operator("object.manipulate_vertex_colors", text="FIFA 14 to FIFA 23 Vertex")
        layout.operator("object.transfer_weights", text="Transfer Weights")
        layout.operator("object.custom_transform", text="Result Transform")

class OBJECT_OT_RenameUVLayers(bpy.types.Operator):
    bl_label = "UV FIFA 14 to FIFA 23"
    bl_idname = "object.rename_uv_layers"

    def execute(self, context):
        rename_uv_layers_()
        return {'FINISHED'}

class OBJECT_OT_ManipulateVertexColors(bpy.types.Operator):
    bl_label = "Vertex FIFA 14 to FIFA 23"
    bl_idname = "object.manipulate_vertex_colors"

    def execute(self, context):
        manipulate_vertex_colors()
        return {'FINISHED'}

class OBJECT_OT_TransferWeights(bpy.types.Operator):
    bl_label = "Transfer Weights"
    bl_idname = "object.transfer_weights"

    def execute(self, context):
        transfer_weights()
        return {'FINISHED'}

classes = (
    KayuhitamPanel,
    OBJECT_OT_RenameUVLayers,
    OBJECT_OT_ManipulateVertexColors,
    OBJECT_OT_TransferWeights,
    OBJECT_OT_custom_transform
)

def register():
    for cls in classes:
        bpy.utils.register_class(cls)

def unregister():
    for cls in classes:
        bpy.utils.unregister_class(cls)

if __name__ == "__main__":
    register()
